#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dnb_igp_setup_interfaces.tag import Tag
from pycatia.system_interfaces.any_object import AnyObject


class RobotMotion(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         RobotMotion
                | 
                | Represents a Robot Motion.
                | 
                | Role: The interface is used to retrieve and set the motion attributes of a
                | Robot Motion.
                | The following code snippet can be used to obtain the Robot Motion from a
                | Operation aggreagted under a Robot Task.
                | 
                |    Dim objOpr as Operation
                |    ...
                |    Dim objRobotmotion as RobotMotion
                |    objOpr.GetRobotMotion objRobotmotion
                |  
                | 
                | 
                | The Robot Motion can also be obtained from an activity of the type
                | RobotMotion.
                | 
                |    Dim objActivity as Activity
                |    ...
                |    Dim objRobotmotion as RobotMotion
                |    Set objRobotmotion = objActivity.GetTechnologicalObject("RobotMotion" )
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.robot_motion = com_object

    def get_accuracy_profile(self, o_accuracy_profile: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAccuracyProfile(AnyObject oAccuracyProfile)
                | 
                |     Retrieves Accuracy profile.
                | 
                |     Parameters:
                | 
                |         oAccuracyProfile
                |             The retrieved profile. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Accuracy Profile was successfully set.
                |         E_FAIL
                |             The Accuracy Profile could not be set.
                | 
                |         Example:
                |             The following example retrieves the Accuracy Profile for the robot
                |             Accuracy.
                | 
                |                Dim objRobotMotion as RobotMotion
                |                Dim AccuracyProfile As String
                |                objRobotMotion.GetAccuracyProfile
                |                AccuracyProfile

        :param AnyObject o_accuracy_profile:
        :rtype: None
        """
        return self.robot_motion.GetAccuracyProfile(o_accuracy_profile.com_object)

    def get_auxillary_axis_home(self, i_device: AnyObject, i_auxillary_axis: str, o_home_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAuxillaryAxisHome(AnyObject iDevice,
                | CATBSTR iAuxillaryAxis,
                | CATBSTR oHomeName)
                | 
                |     Retrieves the underlying Auxillary device Home.
                | 
                |     Parameters:
                | 
                |         iDevice
                |             The Auxillary Device. 
                |         iAuxillaryAxis
                |             Name of the Auxillary Device. 
                |         oHomeName
                |             Home name retrieved for the given Auxillary device.
                |
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The auxillary device target was successfully
                |             retrieved.
                |         E_FAIL
                |             The auxillary device target could not be
                |             retrieved.
                | 
                |         Example:
                |             The following example retrives the home name correspoding to the
                |             target of the auxillary device in a robot motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim Device As Product
                |                ...
                |                Dim DeviceName As String
                |                DeviceName = "Mechanism.1"
                |                Dim HomeName As String
                |                objRobotmotion.GetAuxillaryAxisHome HomeName

        :param AnyObject i_device:
        :param str i_auxillary_axis:
        :param str o_home_name:
        :rtype: None
        """
        return self.robot_motion.GetAuxillaryAxisHome(i_device.com_object, i_auxillary_axis, o_home_name)

    def get_auxillary_axis_values(
            self,
            i_device: AnyObject,
            i_auxillary_axis: str,
            o_auxillary_axis_values: tuple
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAuxillaryAxisValues(AnyObject iDevice,
                | CATBSTR iAuxillaryAxis,
                | CATSafeArrayVariant oAuxillaryAxisValues)
                | 
                |     Retrieves the underlying Auxillary device Joint values.
                | 
                |     Parameters:
                | 
                |         iDevice
                |             Auxillary device (Mechanism) 
                |         iAuxillaryAxis
                |             Name of the auxillary device. 
                |         oAuxillaryAxisValues
                |             List of Joint values retrieved for the given Auxillary device.
                |
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The auxillary device target was successfully
                |             retrieved.
                |         E_FAIL
                |             The auxillary device target could not be
                |             retrieved.
                | 
                |         Example:
                |             The following example sets the joint values correspoding to the
                |             target of the auxillary device in a robot motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim Device As Product
                |                ...
                |                Dim DeviceName As String
                |                DeviceName = "Mechanism.1"
                |                Dim JointTarget(1)
                |                objRobotmotion.GetAuxillaryAxisValues
                |                Device,DeviceName,JointTarget

        :param AnyObject i_device:
        :param str i_auxillary_axis:
        :param tuple o_auxillary_axis_values:
        :rtype: None
        """
        return self.robot_motion.GetAuxillaryAxisValues(i_device.com_object, i_auxillary_axis, o_auxillary_axis_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_auxillary_axis_values'
        # # vba_code = """
        # # Public Function get_auxillary_axis_values(robot_motion)
        # #     Dim iDevice (2)
        # #     robot_motion.GetAuxillaryAxisValues iDevice
        # #     get_auxillary_axis_values = iDevice
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_cartesian_target(self, o_cartesian_target: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCartesianTarget(CATSafeArrayVariant
                | oCartesianTarget)
                | 
                |     Retrieves the Robot Cartesian target.
                | 
                |     Parameters:
                | 
                |         oCartesianTarget
                |             Cartesian Target(The Variant array containing the values in the
                |             sequence X,Y,Z,Yaw,Pitch,Roll) 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The cartesian target was successfully retrieved.
                |         E_FAIL
                |             The cartesian target could not be retrieved.
                | 
                |         Example:
                |             The following example gets the cartesian target for a robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim CartesianTarget(5)
                |                objRobotmotion.GetCartesianTarget
                |                CartesianTarget

        :param tuple o_cartesian_target:
        :rtype: None
        """
        return self.robot_motion.GetCartesianTarget(o_cartesian_target)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_cartesian_target'
        # # vba_code = """
        # # Public Function get_cartesian_target(robot_motion)
        # #     Dim oCartesianTarget (2)
        # #     robot_motion.GetCartesianTarget oCartesianTarget
        # #     get_cartesian_target = oCartesianTarget
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_config(self, o_config_number: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetConfig(short oConfigNumber)
                | 
                |     Retreives the Configuration.
                | 
                |     Parameters:
                | 
                |         oConfigNumber
                |             The Config as a Number. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Configuration was successfully retreived.
                |         E_FAIL
                |             The Configuration could not be retreived.
                | 
                |         Example:
                |             The following example retreives the Configuration for the robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim Config
                |                objRobotmotion.GetConfig Config

        :param int o_config_number:
        :rtype: None
        """
        return self.robot_motion.GetConfig(o_config_number)

    def get_joint_target(self, o_joint_target: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetJointTarget(CATSafeArrayVariant oJointTarget)
                | 
                |     Retrieves the Robot Joint target.
                | 
                |     Parameters:
                | 
                |         oJointTarget
                |             The List of Joint DOF values. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The joint target was successfully retrieved.
                |         E_FAIL
                |             The joint target could not be retrieved.
                | 
                |         Example:
                |             The following example retrieves the joint target of a robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim JointTarget(5)
                |                objRobotmotion.GetJointTarget JointTarget

        :param tuple o_joint_target:
        :rtype: None
        """
        return self.robot_motion.GetJointTarget(o_joint_target)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_joint_target'
        # # vba_code = """
        # # Public Function get_joint_target(robot_motion)
        # #     Dim oJointTarget (2)
        # #     robot_motion.GetJointTarget oJointTarget
        # #     get_joint_target = oJointTarget
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_motion_profile(self, o_motion_profile: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMotionProfile(AnyObject oMotionProfile)
                | 
                |     Retrieves Motion profile.
                | 
                |     Parameters:
                | 
                |         oMotionProfile
                |             The retrieved profile. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Motion Profile was successfully retrieved.
                |         E_FAIL
                |             The Motion Profile could not be retrieved.
                | 
                |         Example:
                |             The following example retrieves the Motion Profile for the robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim MotionProfile As String
                |                objRobotmotion.GetMotionProfile MotionProfile

        :param AnyObject o_motion_profile:
        :rtype: None
        """
        return self.robot_motion.GetMotionProfile(o_motion_profile.com_object)

    def get_motion_type(self, index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMotionType(short index)
                | 
                |     Retrieves the type of Motion.
                | 
                |     Parameters:
                | 
                |         index
                |             The Motion Type
                |             JointMOVE = 0,
                |             LINEARMOVE = 1 ,
                |             PREDEFINED = 2,
                |             CIRCULAR = 3,
                |             CIRCULARVIA = 4,
                |             SLEW = 5
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The motion type was successfully obtained from the robot
                |             motion.
                |         E_FAIL
                |             The motion type could not be obtained.
                | 
                |         Example:
                |             The following example retrieves the motion type for a robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim MotionType
                |                objRobotmotion.GetMotionType MotionType

        :param int index:
        :rtype: None
        """
        return self.robot_motion.GetMotionType(index)

    def get_object_profile(self, o_obj_profile: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetObjectProfile(AnyObject oObjProfile)
                | 
                |     Retrieves Object profile.
                | 
                |     Parameters:
                | 
                |         oObjProfile
                |             The retrieved profile. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The object Profile was successfully retrieved.
                |         E_FAIL
                |             The object Profile could not be retrieved.
                | 
                |         Example:
                |             The following example retrieves the object Profile for the robot
                |             motion.
                | 
                |                Dim objrobotmotion as robotmotion
                |                Dim objectProfile As String
                |                objrobotmotion.GetobjectProfile objectProfile

        :param AnyObject o_obj_profile:
        :rtype: None
        """
        return self.robot_motion.GetObjectProfile(o_obj_profile.com_object)

    def get_orientation_mode(self, index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOrientationMode(short index)
                | 
                |     Retrieves the TCP Orientation Mode.
                | 
                |     Parameters:
                | 
                |         index
                |             Orientation Mode (OneAxis = 0, TwoAxis = 1, ThreeAxis = 2, WristAxis = 3) 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Orientation Mode was successfully retrieved.
                |         E_FAIL
                |             The Orientation Mode could not be retrieved.
                | 
                |         Example:
                |             The following example sets the orientation mode for the robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim OrientationMode
                |                objRobotmotion.GetOrientationMode
                |                OrientationMode

        :param int index:
        :rtype: None
        """
        return self.robot_motion.GetOrientationMode(index)

    def get_tag_target(self, o_tag: Tag) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTagTarget(Tag oTag)
                | 
                |     Retrieves the underlying Tag Target.
                | 
                |     Parameters:
                | 
                |         oTag
                |             The underlying Tag. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The tag target was successfully retrieved.
                |         E_FAIL
                |             The tag target could not be retrieved.
                | 
                |         Example:
                |             The following example retrives the tag target for a robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim objTag as Tag
                |                objRobotmotion.GetTagTarget objTag

        :param Tag o_tag:
        :rtype: None
        """
        return self.robot_motion.GetTagTarget(o_tag.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_tag_target'
        # # vba_code = """
        # # Public Function get_tag_target(robot_motion)
        # #     Dim oTag (2)
        # #     robot_motion.GetTagTarget oTag
        # #     get_tag_target = oTag
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_target_type(self, index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTargetType(short index)
                | 
                |     Retrieves the Target Type.
                | 
                |     Parameters:
                | 
                |         index
                |             Type of the Target (Cartesian = 0, Joint = 1, Tag = 2, Home = 3). 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The target type was successfully obtained from the robot
                |             motion.
                |         E_FAIL
                |             The target type could not be obtained.
                | 
                |         Example:
                |             The following example retrieves the target type for a robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim TargetType
                |                objRobotmotion.GetTargetType TargetType

        :param int index:
        :rtype: None
        """
        return self.robot_motion.GetTargetType(index)

    def get_tool_profile(self, o_tool_profile: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetToolProfile(AnyObject oToolProfile)
                | 
                |     Retrieves tool profile.
                | 
                |     Parameters:
                | 
                |         oToolProfile
                |             The retrieved tool profile. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Tool Profile was successfully retrieved.
                |         E_FAIL
                |             The Tool Profile could not be retrieved.
                | 
                |         Example:
                |             The following example retrieves the Tool Profile for the robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim ToolProfile As String
                |                objRobotmotion.GetToolProfile ToolProfile

        :param AnyObject o_tool_profile:
        :rtype: None
        """
        return self.robot_motion.GetToolProfile(o_tool_profile.com_object)

    def get_turn_numbers(self, o_turn_numbers: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTurnNumbers(CATSafeArrayVariant oTurnNumbers)
                | 
                |     Retrieves the Turn Numbers(or Turn signs) of the robot
                |     motion.
                | 
                |     Parameters:
                | 
                |         oTurnNumbers
                |             The underlying List of TurnNumbers (or turn signs).
                |             
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The turn numbers were successfully obtained.
                |         E_FAIL
                |             The turn numbers could not be obtained.
                | 
                |         Example:
                |             The following example retrives the turn numbers for a robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim TurnNumbers(4)
                |                objRobotmotion.GetTurnNumbers TurnNumbers

        :param tuple o_turn_numbers:
        :rtype: None
        """
        return self.robot_motion.GetTurnNumbers(o_turn_numbers)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_turn_numbers'
        # # vba_code = """
        # # Public Function get_turn_numbers(robot_motion)
        # #     Dim oTurnNumbers (2)
        # #     robot_motion.GetTurnNumbers oTurnNumbers
        # #     get_turn_numbers = oTurnNumbers
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_accuracy_profile(self, i_accuracy_profile: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAccuracyProfile(AnyObject iAccuracyProfile)
                | 
                |     Sets the Accuracy profile.
                | 
                |     Parameters:
                | 
                |         iAccuracyProfile
                |             The Accuracy profile. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Accuracy Profile was successfully set.
                |         E_FAIL
                |             The Accuracy Profile could not be set.
                | 
                |         Example:
                |             The following example retrieves the Accuracy Profile for the robot
                |             Accuracy.
                | 
                |                Dim objRobotMotion as RobotMotion
                |                objRobotMotion.SetAccuracyProfile "Default"

        :param AnyObject i_accuracy_profile:
        :rtype: None
        """
        return self.robot_motion.SetAccuracyProfile(i_accuracy_profile.com_object)

    def set_auxillary_axis_home(self, i_device: AnyObject, i_auxillary_axis: str, i_home_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAuxillaryAxisHome(AnyObject iDevice,
                | CATBSTR iAuxillaryAxis,
                | CATBSTR iHomeName)
                | 
                |     Sets the underlying Auxillary device Home.
                | 
                |     Parameters:
                | 
                |         iDevice
                |             The Auxillary Device. 
                |         iAuxillaryAxis
                |             Name of the Auxillary Device. 
                |         iHomeName
                |             Home name set for the given Auxillary device. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The auxillary device target was successfully set.
                |         E_FAIL
                |             The auxillary device target could not be set.
                | 
                |         Example:
                |             The following example sets the home name correspoding to the target
                |             of the auxillary device in a robot motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim Device As Product
                |                ...
                |                Dim DeviceName As String
                |                DeviceName = "Mechanism.1"
                |                Dim HomeName As String
                |                HomeName = "Home.1"
                |                objRobotmotion.SetAuxillaryAxisHome HomeName

        :param AnyObject i_device:
        :param str i_auxillary_axis:
        :param str i_home_name:
        :rtype: None
        """
        return self.robot_motion.SetAuxillaryAxisHome(i_device.com_object, i_auxillary_axis, i_home_name)

    def set_auxillary_axis_values(
            self,
            i_device: AnyObject,
            i_auxillary_axis: str,
            i_auxillary_axis_values: tuple
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAuxillaryAxisValues(AnyObject iDevice,
                | CATBSTR iAuxillaryAxis,
                | CATSafeArrayVariant iAuxillaryAxisValues)
                | 
                |     Sets the Auxillary device Joint values.
                | 
                |     Parameters:
                | 
                |         iDevice
                |             Auxillary device (Mechanism) 
                |         iAuxillaryAxis
                |             Name of the Auxillary Device. 
                |         iAuxillaryAxisValues
                |             List of joint values of the device. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The auxillary device target was successfully set.
                |         E_FAIL
                |             The auxillary device target could not be set.
                | 
                |         Example:
                |             The following example sets the joint values correspoding to the
                |             target of the auxillary device in a robot motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim Device As Product
                |                ...
                |                Dim DeviceName As String
                |                DeviceName = "Mechanism.1"
                |                Dim JointTarget(1)
                |                JointTarget(0)=1.571
                |                JointTarget(1)=-0.785
                |                objRobotmotion.SetAuxillaryAxisValues
                |                Device,DeviceName,JointTarget

        :param AnyObject i_device:
        :param str i_auxillary_axis:
        :param tuple i_auxillary_axis_values:
        :rtype: None
        """
        return self.robot_motion.SetAuxillaryAxisValues(i_device.com_object, i_auxillary_axis, i_auxillary_axis_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_auxillary_axis_values'
        # # vba_code = """
        # # Public Function set_auxillary_axis_values(robot_motion)
        # #     Dim iDevice (2)
        # #     robot_motion.SetAuxillaryAxisValues iDevice
        # #     set_auxillary_axis_values = iDevice
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_cartesian_target(self, i_cartesian_target: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCartesianTarget(CATSafeArrayVariant
                | iCartesianTarget)
                | 
                |     Sets the Robot Cartesian target.
                | 
                |     Parameters:
                | 
                |         iCartesianTarget
                |             Cartesian Target(The Variant array should contain the values in the
                |             sequence X,Y,Z,Yaw,Pitch,Roll) 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The cartesian target was successfully set.
                |         E_FAIL
                |             The cartesian target could not be set.
                | 
                |         Example:
                |             The following example Sets the cartesian target for a robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim CartesianTarget(5)
                |                CartesianTarget(0)=150
                |                CartesianTarget(1)=200
                |                CartesianTarget(2)=350
                |                CartesianTarget(3)=1.571
                |                CartesianTarget(4)=3.142
                |                CartesianTarget(5)=-0.785
                |                objRobotmotion.SetCartesianTarget
                |                CartesianTarget

        :param tuple i_cartesian_target:
        :rtype: None
        """
        return self.robot_motion.SetCartesianTarget(i_cartesian_target)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_cartesian_target'
        # # vba_code = """
        # # Public Function set_cartesian_target(robot_motion)
        # #     Dim iCartesianTarget (2)
        # #     robot_motion.SetCartesianTarget iCartesianTarget
        # #     set_cartesian_target = iCartesianTarget
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_config(self, i_config_number: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetConfig(short iConfigNumber)
                | 
                |     Sets the Configuration for the robot motion.
                | 
                |     Parameters:
                | 
                |         iConfigNumber
                |             The Config as a Number. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Configuration was successfully set.
                |         E_FAIL
                |             The Configuration could not be set.
                | 
                |         Example:
                |             The following example sets the configuration for the robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                objRobotmotion.SetConfig 1

        :param int i_config_number:
        :rtype: None
        """
        return self.robot_motion.SetConfig(i_config_number)

    def set_joint_target(self, i_joint_target: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetJointTarget(CATSafeArrayVariant iJointTarget)
                | 
                |     Sets the Robot Joint target.
                | 
                |     Parameters:
                | 
                |         iJointTarget
                |             The List of Joint DOF values. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The joint target was successfully set.
                |         E_FAIL
                |             The joint target could not be set.
                | 
                |         Example:
                |             The following example sets the joint target for a robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim JointTarget(5)
                |                JointTarget(0)=1.571
                |                JointTarget(1)=-0.785
                |                JointTarget(2)=3.142
                |                JointTarget(3)=0.38
                |                JointTarget(4)=1.57
                |                JointTarget(5)=0.6
                |                objRobotmotion.SetJointTarget JointTarget

        :param tuple i_joint_target:
        :rtype: None
        """
        return self.robot_motion.SetJointTarget(i_joint_target)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_joint_target'
        # # vba_code = """
        # # Public Function set_joint_target(robot_motion)
        # #     Dim iJointTarget (2)
        # #     robot_motion.SetJointTarget iJointTarget
        # #     set_joint_target = iJointTarget
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_motion_profile(self, i_motion_profile: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMotionProfile(AnyObject iMotionProfile)
                | 
                |     Sets the Motion profile.
                | 
                |     Parameters:
                | 
                |         iMotionProfile
                |             The Motion profile. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Motion Profile was successfully set.
                |         E_FAIL
                |             The Motion Profile could not be set.
                | 
                |         Example:
                |             The following example retrieves the Motion Profile for the robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                objRobotmotion.SetMotionProfile "Default"

        :param AnyObject i_motion_profile:
        :rtype: None
        """
        return self.robot_motion.SetMotionProfile(i_motion_profile.com_object)

    def set_motion_type(self, index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMotionType(short index)
                | 
                |     Sets the type of Motion.
                | 
                |     Parameters:
                | 
                |         index
                |             The Motion Type
                |             JointMOVE = 0,
                |             LINEARMOVE = 1 ,
                |             PREDEFINED = 2,
                |             CIRCULAR = 3,
                |             CIRCULARVIA = 4, SLEW = 5
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The motion type was successfully set to the robot
                |             motion.
                |         E_FAIL
                |             The motion type could not be set.
                | 
                |         Example:
                |             The following example Sets the motion type for a robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                objRobotmotion.SetMotionType 1

        :param int index:
        :rtype: None
        """
        return self.robot_motion.SetMotionType(index)

    def set_object_profile(self, i_obj_profile: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetObjectProfile(AnyObject iObjProfile)
                | 
                |     Sets the Object profile.
                | 
                |     Parameters:
                | 
                |         iObjProfile
                |             The Object profile. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Object Profile was successfully set.
                |         E_FAIL
                |             The Object Profile could not be set.
                | 
                |         Example:
                |             The following example retrieves the Object Profile for the robot
                |             Object.
                | 
                |                Dim objRobotMotion as RobotMotion
                |                Dim ObjectProfile As String
                |                objRobotMotion.SetObjectProfile "Default"

        :param AnyObject i_obj_profile:
        :rtype: None
        """
        return self.robot_motion.SetObjectProfile(i_obj_profile.com_object)

    def set_orientation_mode(self, index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOrientationMode(short index)
                | 
                |     Sets the TCP Orientation Mode.
                | 
                |     Parameters:
                | 
                |         index
                |             Orientation Mode (OneAxis = 0, TwoAxis = 1, ThreeAxis = 2, WristAxis = 3) 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Orientation Mode was successfully set.
                |         E_FAIL
                |             The Orientation Mode could not be set.
                | 
                |         Example:
                |             The following example sets the orientation mode for the robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                objRobotmotion.SetOrientationMode 1

        :param int index:
        :rtype: None
        """
        return self.robot_motion.SetOrientationMode(index)

    def set_tag_target(self, i_tag: Tag) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTagTarget(Tag iTag)
                | 
                |     Sets the Robot Tag target.
                | 
                |     Parameters:
                | 
                |         iTag
                |             The Tag to Set as the target. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The tag target was successfully set.
                |         E_FAIL
                |             The tag target could not be set.
                | 
                |         Example:
                |             The following example sets the tag target for a robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim objTag as Tag
                |                ...
                |                objRobotmotion.SetTagTarget objTag

        :param Tag i_tag:
        :rtype: None
        """
        return self.robot_motion.SetTagTarget(i_tag.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_tag_target'
        # # vba_code = """
        # # Public Function set_tag_target(robot_motion)
        # #     Dim iTag (2)
        # #     robot_motion.SetTagTarget iTag
        # #     set_tag_target = iTag
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_tool_profile(self, i_tool_profile: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetToolProfile(AnyObject iToolProfile)
                | 
                |     Sets the Tool profile.
                | 
                |     Parameters:
                | 
                |         iToolProfile
                |             The Tool profile. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Tool Profile was successfully set.
                |         E_FAIL
                |             The Tool Profile could not be set.
                | 
                |         Example:
                |             The following example retrieves the Tool Profile for the robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                objRobotmotion.SetToolProfile "Default"

        :param AnyObject i_tool_profile:
        :rtype: None
        """
        return self.robot_motion.SetToolProfile(i_tool_profile.com_object)

    def set_turn_numbers(self, i_turn_numbers: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTurnNumbers(CATSafeArrayVariant iTurnNumbers)
                | 
                |     Sets Turn Numbers or Turn signs for the robot motion.
                | 
                |     Parameters:
                | 
                |         iTurnNumbers
                |             The List of Turn numbers (or turn signs) to be set.
                |             
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The turn numbers were successfully set.
                |         E_FAIL
                |             The turn numbers could not be set.
                | 
                |         Example:
                |             The following example sets the turn numbers for a robot
                |             motion.
                | 
                |                Dim objRobotmotion as RobotMotion
                |                Dim TurnNumbers(4)
                |                TurnNumbers(0)=1
                |                TurnNumbers(1)=-1
                |                TurnNumbers(2)=0
                |                TurnNumbers(3)=2
                |                objRobotmotion.SetTurnNumbers TurnNumbers

        :param tuple i_turn_numbers:
        :rtype: None
        """
        return self.robot_motion.SetTurnNumbers(i_turn_numbers)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_turn_numbers'
        # # vba_code = """
        # # Public Function set_turn_numbers(robot_motion)
        # #     Dim iTurnNumbers (2)
        # #     robot_motion.SetTurnNumbers iTurnNumbers
        # #     set_turn_numbers = iTurnNumbers
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'RobotMotion(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class Group(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Group
                | 
                | Represents a DMU group.
                | The DMU group is an entity which gathers references to several products in
                | order to automate validation and verification of the Digital
                | Mock-Up.
                | 
                | A user can build a group using several methods: explicitely point out some
                | products or take all products by default. The designated products can be
                | intermediate or terminal node of the product structure. For instance, a user
                | who has to verify the integration of the engine in engine bay may define a
                | group with the engine assembly or with all the parts from the engine in order
                | to detect clashes. In the first case this user has to add the engine assembly
                | (as a product) in the group, and in the second case, to add all the parts to
                | the group. Obviously, when a modification happens to the engine assembly the
                | user has to change the group only in the second case. To manage the explicit
                | definition of the group, one may use the XxxxExplicit methods.
                | 
                | When the system takes the group into account to perform a given task, it may be
                | necessary to retrieve:
                | 
                |     The products designated by the user (For example, the section of these
                |     products)
                |     The terminal nodes (or leaves) of the product (For example, clash detection
                |     takes into account terminal nodes)
                |     The set of products in the product structure which are not selected (For
                |     example, hide all products which are not in the group)
                |     The set of terminal nodes which are not selected (For example, clash of
                |     some products against all others). 
                | 
                | To perform these treatments one may use YyyyExtract or ZzzzInvert
                | methods.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.group = com_object

    @property
    def extract_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExtractMode() As long
                | 
                |     Returns or sets the mode for the extraction methods.
                | 
                |     Returns:
                |         The extraction mode
                | 
                |             0: the extraction provides the products from the group
                |             (intermediate of terminal nodes).
                |             1: the extraction provides terminal nodes of the products from the
                |             group. 
                | 
                |     Example:
                | 
                |              This example retrieves the extraction mode of the NewGroup Group
                |              and sets it to 1.
                |             
                | 
                |             Dim Mode As Integer
                |             Mode = NewGroup.ExtractMode
                |             NewGroup.ExtractMode = 1

        :rtype: int
        """

        return self.group.ExtractMode

    @extract_mode.setter
    def extract_mode(self, value: int):
        """
        :param int value:
        """

        self.group.ExtractMode = value

    def add_explicit(self, i_product: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddExplicit(CATBaseDispatch iProduct)
                | 
                |     Adds a product to the group.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product to add 
                | 
                |     Example:
                | 
                |              This example adds the product MyProduct to the group
                |              NewGroup.
                |             
                | 
                |             NewGroup.AddExplicit MyProduct

        :param AnyObject i_product:
        :rtype: None
        """
        return self.group.AddExplicit(i_product.com_object)

    def count_explicit(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CountExplicit() As long
                | 
                |     Returns the number of products in the group.
                | 
                |     Example:
                | 
                |              This example retrieves the number of products in the group
                |              NewGroup.
                |             
                | 
                |             Dim number As Integer
                |             number = NewGroup.CountExplicit

        :rtype: int
        """
        return self.group.CountExplicit()

    def count_extract(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CountExtract() As long
                | 
                |     Returns the number of products which can be extracted from the
                |     group.
                | 
                |     Depending on the extraction mode, the extracted products can
                |     be:
                | 
                |         Mode = 0: the products from the group (intermediate or terminal nodes).
                |         Mode = 1: the terminal nodes of the products from the group. 
                | 
                |     Returns:
                |         The number of products 
                |     Example:
                | 
                |              This example reads the number of products in the group
                |              NewGroup.
                |             
                | 
                |             Dim number As Integer
                |             number = NewGroup.CountExtract

        :rtype: int
        """
        return self.group.CountExtract()

    def count_invert(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CountInvert() As long
                | 
                |     Returns the number of terminal node products which cannot be extracted from
                |     the group.
                | 
                |     Example:
                | 
                |              This example retrieves the number of terminal node products which
                |              cannot be extracted from the group NewGroup.
                |             
                | 
                |             Dim number As Integer
                |             number = NewGroup.CountInvert

        :rtype: int
        """
        return self.group.CountInvert()

    def fill_sel_with_extract(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub FillSelWithExtract()
                | 
                |     Fills the selection with all products which can be extracted from the
                |     group.
                | 
                |     Example:
                | 
                |              This example fills the selection with products which can be
                |              extracted
                |             from the NewGroup group.
                |             
                | 
                |             NewGroup.FillSelWithExtract

        :rtype: None
        """
        return self.group.FillSelWithExtract()

    def fill_sel_with_invert(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub FillSelWithInvert()
                | 
                |     Fills the selection with all terminal node products which cannot be
                |     extracted from the group.
                | 
                |     Example:
                | 
                |              This example fills the selection with all products which cannnot
                |              be extracted
                |             from the NewGroup group.
                |             
                | 
                |             NewGroup.FillSelWithInvert

        :rtype: None
        """
        return self.group.FillSelWithInvert()

    def item_explicit(self, i_index: cat_variant) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func ItemExplicit(CATVariant iIndex) As CATBaseDispatch
                | 
                |     Returns a product using its index in the group.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the product in the group. The index of the first
                |             product is 1, and the index of the last product is CountExplicit.
                |             
                | 
                |     Returns:
                |         The retrieved product 
                |     Example:
                | 
                |              This example retrieves in ThisProduct the ninth
                |              product
                |             from the NewGroup group.
                |             
                | 
                |             Dim ThisProduct As Product
                |             Set ThisProduct = NewGroup.ItemExplicit(9)

        :param cat_variant i_index:
        :rtype: AnyObject
        """
        return self.group.ItemExplicit(i_index)

    def item_extract(self, i_index: cat_variant) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func ItemExtract(CATVariant iIndex) As Product
                | 
                |     Returns a product which can be extracted from the group using its
                |     index.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the product in the group. The index of the first
                |             product is 1, and the index of the last product is CountExtract.
                |             
                | 
                |     Returns:
                |         The retrieved product 
                |     Example:
                | 
                |              This example retrieves in ThisProduct the ninth
                |              product
                |             from the NewGroup group.
                |             
                | 
                |             Dim ThisProduct As Group
                |             Set ThisProduct = NewGroup.ItemExtract(9)

        :param cat_variant i_index:
        :rtype: Product
        """
        return Product(self.group.ItemExtract(i_index))

    def item_invert(self, i_index: cat_variant) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func ItemInvert(CATVariant iIndex) As Product
                | 
                |     Returns a terminal node product which cannot be extracted from the group
                |     using its index.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the product in the group. The index of the first
                |             product is 1, and the index of the last product is CountExtract.
                |             
                | 
                |     Returns:
                |         The retrieved product 
                |     Example:
                | 
                |              This example retrieves in ThisProduct the ninth product which
                |              cannot be extracted from 
                |             the NewGroup group.
                |             
                | 
                |             Dim ThisProduct As Group
                |             Set ThisProduct = NewGroup.ItemInvert(9)

        :param cat_variant i_index:
        :rtype: Product
        """
        return Product(self.group.ItemInvert(i_index))

    def remove_explicit(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveExplicit(CATVariant iIndex)
                | 
                |     Removes a product from the group using its index.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the product in the group. The index of the first
                |             product is 1, and the index of the last product is CountExplicit.
                |             
                | 
                |     Example:
                | 
                |              The following example removes the tenth product from the NewGroup
                |              group.
                |             
                | 
                |             NewGroup.RemoveExplicit 10

        :param cat_variant i_index:
        :rtype: None
        """
        return self.group.RemoveExplicit(i_index)

    def __repr__(self):
        return f'Group(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class Export3DXmlSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         Export3DXmlSettingAtt
                | 
                | Represents a setting controller for the 3D XML export
                | settings.
                | Role: This interface is implemented by a component which represents the
                | controller of the 3D XML export settings.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.export_3d_xml_setting_att = com_object

    @property
    def alternate_view(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AlternateView() As boolean
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.get_DesignReview Returns or sets the alternate view
                |         activation flag.
                | 
                |         Example:
                |             This example activates the alternate view export.
                | 
                |               
                |               export3DXmlSettingAtt.AlternateView = True

        :rtype: bool
        """

        return self.export_3d_xml_setting_att.AlternateView

    @alternate_view.setter
    def alternate_view(self, value: bool):
        """
        :param bool value:
        """

        self.export_3d_xml_setting_att.AlternateView = value

    @property
    def animation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Animation() As boolean
                | 
                |     Returns or sets the animation activation flag.
                | 
                |     Example:
                |         This example activates the animation export.
                | 
                |           
                |           export3DXmlSettingAtt.Animation = True

        :rtype: bool
        """

        return self.export_3d_xml_setting_att.Animation

    @animation.setter
    def animation(self, value: bool):
        """
        :param bool value:
        """

        self.export_3d_xml_setting_att.Animation = value

    @property
    def annotated_view(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnnotatedView() As boolean
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.get_DesignReview Returns or sets the annotated view
                |         activation flag.
                | 
                |         Example:
                |             This example activates the annotated view export.
                | 
                |               
                |               export3DXmlSettingAtt.AnnotatedView = True

        :rtype: bool
        """

        return self.export_3d_xml_setting_att.AnnotatedView

    @annotated_view.setter
    def annotated_view(self, value: bool):
        """
        :param bool value:
        """

        self.export_3d_xml_setting_att.AnnotatedView = value

    @property
    def annotation_3d(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Annotation3D() As boolean
                | 
                |     Returns or sets the 3D annotation activation flag.
                | 
                |     Example:
                |         This example activates the 3D annotation export.
                | 
                |           
                |           export3DXmlSettingAtt.Annotation3D = True

        :rtype: bool
        """

        return self.export_3d_xml_setting_att.Annotation3D

    @annotation_3d.setter
    def annotation_3d(self, value: bool):
        """
        :param bool value:
        """

        self.export_3d_xml_setting_att.Annotation3D = value

    @property
    def design_review(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DesignReview() As boolean
                | 
                |     Returns or sets the Design Review activation flag.
                | 
                |     Example:
                |         This example activates the Design Review export.
                | 
                |           
                |           export3DXmlSettingAtt.DesignReview = True

        :rtype: bool
        """

        return self.export_3d_xml_setting_att.DesignReview

    @design_review.setter
    def design_review(self, value: bool):
        """
        :param bool value:
        """

        self.export_3d_xml_setting_att.DesignReview = value

    @property
    def geometry_representation_format(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GeometryRepresentationFormat() As
                | Cat3DXmlGeomRepresentationType
                | 
                |     Returns or sets the format of geometry representation.
                | 
                |     Example:
                |         This example sets the representation format to the exact
                |         mode.
                | 
                |           
                |           export3DXmlSettingAtt.GeometryRepresentationFormat = cat3DXmlExact

        :return: enum cat_3d_xml_geom_representation_type
        :rtype: int
        """

        return self.export_3d_xml_setting_att.GeometryRepresentationFormat

    @geometry_representation_format.setter
    def geometry_representation_format(self, value: int):
        """
        :param int value:
        """

        self.export_3d_xml_setting_att.GeometryRepresentationFormat = value

    @property
    def measure(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Measure() As boolean
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.get_DesignReview Returns or sets the measure activation
                |         flag.
                | 
                |         Example:
                |             This example activates the measure export.
                | 
                |               
                |               export3DXmlSettingAtt.Measure = True

        :rtype: bool
        """

        return self.export_3d_xml_setting_att.Measure

    @measure.setter
    def measure(self, value: bool):
        """
        :param bool value:
        """

        self.export_3d_xml_setting_att.Measure = value

    @property
    def ppr_save_config(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PPRSaveConfig() As Cat3DXmlPPRSaveConfig
                | 
                |     Returns or sets the PPR config.
                | 
                |     Example:
                |         This example sets the PPR config. Product And resources export is
                |         acivated.
                | 
                |           
                |           export3DXmlSettingAtt.PPRSaveConfig = cat3DXmlProductAndResourceList

        :return: enum cat_3d_xml_ppr_save_config
        :rtype: int
        """

        return self.export_3d_xml_setting_att.PPRSaveConfig

    @ppr_save_config.setter
    def ppr_save_config(self, value: int):
        """
        :param int value: enum cat_3d_xml_ppr_save_config
        """

        self.export_3d_xml_setting_att.PPRSaveConfig = value

    @property
    def presentation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Presentation() As boolean
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.get_DesignReview Returns or sets the presentation
                |         activation flag.
                | 
                |         Example:
                |             This example activates the presentation export.
                | 
                |               
                |               export3DXmlSettingAtt.Presentation = True

        :rtype: bool
        """

        return self.export_3d_xml_setting_att.Presentation

    @presentation.setter
    def presentation(self, value: bool):
        """
        :param bool value:
        """

        self.export_3d_xml_setting_att.Presentation = value

    @property
    def section(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Section() As boolean
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.get_DesignReview Returns or sets the section activation
                |         flag.
                | 
                |         Example:
                |             This example activates the section export.
                | 
                |               
                |               export3DXmlSettingAtt.Section = True

        :rtype: bool
        """

        return self.export_3d_xml_setting_att.Section

    @section.setter
    def section(self, value: bool):
        """
        :param bool value:
        """

        self.export_3d_xml_setting_att.Section = value

    @property
    def surface_accuracy(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SurfaceAccuracy() As float
                | 
                |     Returns or sets the surface accuracy.
                | 
                |     Example:
                |         This example sets the surface accuracy used by the exact
                |         mode.
                | 
                |           
                |           export3DXmlSettingAtt.SurfaceAccuracy = 0.01

        :rtype: float
        """

        return self.export_3d_xml_setting_att.SurfaceAccuracy

    @surface_accuracy.setter
    def surface_accuracy(self, value: float):
        """
        :param float value:
        """

        self.export_3d_xml_setting_att.SurfaceAccuracy = value

    @property
    def work_instructions(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WorkInstructions() As boolean
                | 
                |     Returns or sets the Work Instructions activation flag.
                | 
                |     Example:
                |         This example activates the Work Instructions export.
                | 
                |           
                |           export3DXmlSettingAtt.DesignReview = True

        :rtype: bool
        """

        return self.export_3d_xml_setting_att.WorkInstructions

    @work_instructions.setter
    def work_instructions(self, value: bool):
        """
        :param bool value:
        """

        self.export_3d_xml_setting_att.WorkInstructions = value

    def get_alternate_view_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAlternateViewInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.GetDesignReviewInfo Retrieves environment informations
                |         for the alternate view setting.
                |         Role:Retrieves the state of the alternate view setting in the current
                |         environment. 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetAlternateViewInfo(io_admin_level, io_locked)

    def get_animation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnimationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the animation
                |     setting.
                |     Role:Retrieves the state of the animation setting in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetAnimationInfo(io_admin_level, io_locked)

    def get_annotated_view_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnnotatedViewInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.GetDesignReviewInfo Retrieves environment informations
                |         for the annotated view setting.
                |         Role:Retrieves the state of the annotated view setting in the current
                |         environment. 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetAnnotatedViewInfo(io_admin_level, io_locked)

    def get_annotation_3d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnnotation3DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the 3D annotation
                |     setting.
                |     Role:Retrieves the state of the 3D annotation setting in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetAnnotation3DInfo(io_admin_level, io_locked)

    def get_design_review_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDesignReviewInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Design Review
                |     setting.
                |     Role:Retrieves the state of the Design Review setting in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetDesignReviewInfo(io_admin_level, io_locked)

    def get_geometry_representation_format_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetGeometryRepresentationFormatInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the geometry representation format
                |     setting.
                |     Role:Retrieves the state of the parameter geometry representation format
                |     setting in the current environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetGeometryRepresentationFormatInfo(io_admin_level, io_locked)

    def get_measure_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMeasureInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.GetDesignReviewInfo Retrieves environment informations
                |         for the measure setting.
                |         Role:Retrieves the state of the measure setting in the current
                |         environment. 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetMeasureInfo(io_admin_level, io_locked)

    def get_ppr_save_config_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPPRSaveConfigInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PPRSaveConfig
                |     setting.
                |     Role:Retrieves the state of the PPRSaveConfig setting in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetPPRSaveConfigInfo(io_admin_level, io_locked)

    def get_presentation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPresentationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.GetDesignReviewInfo Retrieves environment informations
                |         for the presentation setting.
                |         Role:Retrieves the state of the presentation setting in the current
                |         environment. 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetPresentationInfo(io_admin_level, io_locked)

    def get_section_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSectionInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.GetDesignReviewInfo Retrieves environment informations
                |         for the section setting.
                |         Role:Retrieves the state of the section setting in the current
                |         environment. 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetSectionInfo(io_admin_level, io_locked)

    def get_surface_accuracy_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSurfaceAccuracyInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the surface accuracy
                |     setting.
                |     Role:Retrieves the state of the surface accuracy setting in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetSurfaceAccuracyInfo(io_admin_level, io_locked)

    def get_work_instructions_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWorkInstructionsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Work Instructions
                |     setting.
                |     Role:Retrieves the state of the Work Instructions setting in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.export_3d_xml_setting_att.GetWorkInstructionsInfo(io_admin_level, io_locked)

    def set_alternate_view_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAlternateViewLock(boolean iLocked)
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.SetDesignReviewLock Locks or unlocks the
                |         flag.
                |         Role:Locks or unlocks the parameter if it is possible in the current
                |         administrated. In user mode this method will always return E_FAIL.
                |         
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetAlternateViewLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_alternate_view_lock'
        # # vba_code = """
        # # Public Function set_alternate_view_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetAlternateViewLock iLocked
        # #     set_alternate_view_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_animation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnimationLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetAnimationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_animation_lock'
        # # vba_code = """
        # # Public Function set_animation_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetAnimationLock iLocked
        # #     set_animation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_annotated_view_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnnotatedViewLock(boolean iLocked)
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.SetDesignReviewLock Locks or unlocks the
                |         flag.
                |         Role:Locks or unlocks the parameter if it is possible in the current
                |         administrated. In user mode this method will always return E_FAIL.
                |         
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetAnnotatedViewLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_annotated_view_lock'
        # # vba_code = """
        # # Public Function set_annotated_view_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetAnnotatedViewLock iLocked
        # #     set_annotated_view_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_annotation_3d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnnotation3DLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetAnnotation3DLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_annotation3_d_lock'
        # # vba_code = """
        # # Public Function set_annotation3_d_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetAnnotation3DLock iLocked
        # #     set_annotation3_d_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_design_review_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDesignReviewLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetDesignReviewLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_design_review_lock'
        # # vba_code = """
        # # Public Function set_design_review_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetDesignReviewLock iLocked
        # #     set_design_review_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_geometry_representation_format_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGeometryRepresentationFormatLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetGeometryRepresentationFormatLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_geometry_representation_format_lock'
        # # vba_code = """
        # # Public Function set_geometry_representation_format_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetGeometryRepresentationFormatLock iLocked
        # #     set_geometry_representation_format_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_measure_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMeasureLock(boolean iLocked)
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.SetDesignReviewLock Locks or unlocks the
                |         flag.
                |         Role:Locks or unlocks the parameter if it is possible in the current
                |         administrated. In user mode this method will always return E_FAIL.
                |         
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetMeasureLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_measure_lock'
        # # vba_code = """
        # # Public Function set_measure_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetMeasureLock iLocked
        # #     set_measure_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ppr_save_config_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPPRSaveConfigLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetPPRSaveConfigLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ppr_save_config_lock'
        # # vba_code = """
        # # Public Function set_ppr_save_config_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetPPRSaveConfigLock iLocked
        # #     set_ppr_save_config_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_presentation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPresentationLock(boolean iLocked)
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.SetDesignReviewLock Locks or unlocks the
                |         flag.
                |         Role:Locks or unlocks the parameter if it is possible in the current
                |         administrated. In user mode this method will always return E_FAIL.
                |         
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetPresentationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_presentation_lock'
        # # vba_code = """
        # # Public Function set_presentation_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetPresentationLock iLocked
        # #     set_presentation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_section_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSectionLock(boolean iLocked)
                | 
                |     Deprecated:
                |         R19 This method will be replaced by
                |         Export3DXmlSettingAtt.SetDesignReviewLock Locks or unlocks the
                |         flag.
                |         Role:Locks or unlocks the parameter if it is possible in the current
                |         administrated. In user mode this method will always return E_FAIL.
                |         
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetSectionLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_section_lock'
        # # vba_code = """
        # # Public Function set_section_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetSectionLock iLocked
        # #     set_section_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_surface_accuracy_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSurfaceAccuracyLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetSurfaceAccuracyLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_surface_accuracy_lock'
        # # vba_code = """
        # # Public Function set_surface_accuracy_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetSurfaceAccuracyLock iLocked
        # #     set_surface_accuracy_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_work_instructions_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetWorkInstructionsLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.export_3d_xml_setting_att.SetWorkInstructionsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_work_instructions_lock'
        # # vba_code = """
        # # Public Function set_work_instructions_lock(export3_d_xml_setting_att)
        # #     Dim iLocked (2)
        # #     export3_d_xml_setting_att.SetWorkInstructionsLock iLocked
        # #     set_work_instructions_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Export3DXmlSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.cat_tps_interfaces.tps_parallel_on_screen import TPSParallelOnScreen
from pycatia.types.general import cat_variant


class FlagNote(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     FlagNote
                | 
                | Interface for the TPS Flag Note object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.flag_note = com_object

    @property
    def flag_note_text(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FlagNoteText() As CATBSTR
                | 
                |     Retrieves or sets Flag Text.
                | 
                |     Parameters:
                | 
                |         oText
                |             Returned Flag text.

        :rtype: str
        """

        return self.flag_note.FlagNoteText

    @flag_note_text.setter
    def flag_note_text(self, value: str):
        """
        :param str value:
        """

        self.flag_note.FlagNoteText = value

    @property
    def text(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Text() As CATBSTR
                | 
                |     Retrieves or sets Flag Text Representation.
                | 
                |     Parameters:
                | 
                |         oText
                |             Returned text for graphical representation.

        :rtype: str
        """

        return self.flag_note.Text

    @text.setter
    def text(self, value: str):
        """
        :param str value:
        """

        self.flag_note.Text = value

    def add_url(self, i_url: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddURL(CATBSTR iUrl)
                | 
                |     Sets an URL.
                | 
                |     Parameters:
                | 
                |         iUrl
                |             URL to Set

        :param str i_url:
        :rtype: None
        """
        return self.flag_note.AddURL(i_url)

    def get_nbr_url(self, o_number_of_url: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetNbrURL(CATVariant oNumberOfURL)
                | 
                |     Deprecated:
                |         V5-6R2017 This method is replaced by FlagNote.GetNbrURL2

        :param cat_variant o_number_of_url:
        :rtype: None
        """
        return self.flag_note.GetNbrURL(o_number_of_url)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_nbr_url'
        # # vba_code = """
        # # Public Function get_nbr_url(flag_note)
        # #     Dim oNumberOfURL (2)
        # #     flag_note.GetNbrURL oNumberOfURL
        # #     get_nbr_url = oNumberOfURL
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_nbr_url2(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNbrURL2() As long
                | 
                |     Gets the number of URL.
                | 
                |     Parameters:
                | 
                |         oNumberOfURL
                |             returns param oNumberOfURL.

        :rtype: int
        """
        return self.flag_note.GetNbrURL2()

    def modify_url(self, i_url: str, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ModifyURL(CATBSTR iUrl,
                | CATVariant iIndex)
                | 
                |     Modifies an URL.
                | 
                |     Parameters:
                | 
                |         iUrl
                |             URL to Set. 
                |         iIndex
                |             index of the URL to modify.

        :param str i_url:
        :param cat_variant i_index:
        :rtype: None
        """
        return self.flag_note.ModifyURL(i_url, i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'modify_url'
        # # vba_code = """
        # # Public Function modify_url(flag_note)
        # #     Dim iUrl (2)
        # #     flag_note.ModifyURL iUrl
        # #     modify_url = iUrl
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_url(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveURL(CATVariant iIndex)
                | 
                |     Remove an URL.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             position of the URL to remove.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.flag_note.RemoveURL(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_url'
        # # vba_code = """
        # # Public Function remove_url(flag_note)
        # #     Dim iIndex (2)
        # #     flag_note.RemoveURL iIndex
        # #     remove_url = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def tps_parallel_on_screen(self) -> TPSParallelOnScreen:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func TPSParallelOnScreen() As TPSParallelOnScreen
                | 
                |     Gets the annotation on TPSParallelOnScreen interface.

        :rtype: TPSParallelOnScreen
        """
        return TPSParallelOnScreen(self.flag_note.TPSParallelOnScreen())

    def url(self, i_index: cat_variant) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func URL(CATVariant iIndex) As CATBSTR
                | 
                |     Retrieves URL.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             Index of URL. 
                |         oUrl
                |             URL

        :param cat_variant i_index:
        :rtype: str
        """
        return self.flag_note.URL(i_index)

    def __repr__(self):
        return f'FlagNote(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.kinematics_interfaces.dressup import Dressup
from pycatia.kinematics_interfaces.mechanism import Mechanism
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Dressups(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Dressups
                | 
                | A collection of all Dressup entities currently managed by the
                | application.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dressups = com_object

    def add(self, i_mechanism: Mechanism, i_context: Product) -> Dressup:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Mechanism iMechanism,
                | Product iContext) As Dressup
                | 
                |     Creates a new Dressup and adds it to the Dressups
                |     collection.
                | 
                |     Parameters:
                | 
                |         iMechanism
                |             The mechanism on which the dressup will apply. 
                |         iContext
                |             The Context product on which the mechanism is defined
                |
                |     Returns:
                |         The created Dressup 
                |     Example:
                |         This example creates a new Dressup in the TheDressups
                |         collection.
                | 
                |             Dim NewDressup As Dressup
                |             Set NewDressup = TheDressups.Add(Mechanism)

        :param Mechanism i_mechanism:
        :param Product i_context:
        :rtype: Dressup
        """
        return Dressup(self.dressups.Add(i_mechanism.com_object, i_context.com_object))

    def item(self, i_index: cat_variant) -> Dressup:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Dressup
                | 
                |     Returns a Dressup using its index or its name from the Dressups
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Dressup to retrieve from the
                |             collection of Dressups. As a numerics, this index is the rank of the Dressup in
                |             the collection. The index of the first Dressup in the collection is 1, and the
                |             index of the last Dressup is Count. As a string, it is the name you assigned to
                |             the Dressup using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved Dressup 
                |     Example:
                |         This example returns in ThisDressup the third Dressup in the
                |         collection, and in ThatDressup the Dressup named
                |         MyDressup.
                | 
                |          Dim ThisDressup As Dressup
                |          Set ThisDressup = TheDressups.Item(3)
                |          Dim ThatDressup As Dressup
                |          Set ThatDressup = CATIA.Dressups.Item("MyDressup")

        :param cat_variant i_index:
        :rtype: Dressup
        """
        return Dressup(self.dressups.Item(i_index))

    def list_mechanisms_context(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListMechanismsContext() As CATSafeArrayVariant
                | 
                |     Each mechanism of the list given by ListPossibleMechanisms has a context
                |     product on which it is defined.
                | 
                |     Parameters:
                | 
                |         Nothing
                | 
                |     Returns:
                |         The list of mechanisms' contexts on which a dressup can be created. The
                |         context of oMechanismList(i) is oContextList(i). 
                |     Example:
                |         The following example returns the first and the last element of the
                |         list of mechanisms' contexts. We assume that this list contains at least two
                |         values.
                | 
                |             Dim ContextList As Product
                |             ContextList = MyDressups.ListMechanismsContext()
                |             Dim FirstContext As Product
                |             Set FirstContext = ContextList(0) 
                |             Dim LastContext As Product
                |             Set LastContext = ContextList(ubound(ContextList))

        :rtype: tuple
        """
        return self.dressups.ListMechanismsContext()

    def list_possible_mechanisms(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListPossibleMechanisms() As CATSafeArrayVariant
                | 
                |     Returns information about all possible mechanisms on which a dressup can be
                |     created.
                | 
                |     Parameters:
                | 
                |         Nothing
                | 
                |     Returns:
                |         The list of possible mechanisms on which a dressup can be created.
                |         
                |     Example:
                |         The following example returns the first and the last element of the
                |         list of possible mechanisms. We assume that this list contains at least two
                |         values.
                | 
                |             Dim PossibleMecList As Mechanism
                |             PossibleMecList = MyDressups.ListPossibleMechanisms()
                |             Dim FirstMeca As Mechanism
                |             Set Meca  = PossibleMecList(0) 
                |             Dim LastMeca As Mechanism
                |             Set Meca  = PossibleMecList(ubound(PossibleMecList))

        :rtype: tuple
        """
        return self.dressups.ListPossibleMechanisms()

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a Dressup from the Dressups collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Dressup to retrieve from the
                |             collection of Dressups. As a numerics, this index is the rank of the Dressup in
                |             the collection. The index of the first Dressup in the collection is 1, and the
                |             index of the last Dressup is Count. As a string, it is the name you assigned to
                |             the Dressup. 
                | 
                |     Returns:
                |         Nothing 
                |     Example:
                |         The following example removes the tenth Dressup and the Dressup named
                |         DressupTwo from the TheDressups collection.
                | 
                |             TheDressups.Remove(10)
                |             TheDressups.Remove("DressupTwo")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.dressups.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(dressups)
        # #     Dim iIndex (2)
        # #     dressups.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Dressups(name="{self.name}")'
